/*----------------------------------------------------------------------
 * Meeting.java
 * ---------------------------------------------------------------------
 * Purpose:	Objects of this class represent meetings contained within
 * 			the CMRadar .meetings file.  Meetings have an id, initiator,
 * 			duration, type, weight, and attendants.  Meeting Objects are
 * 			used by RoomSearch.java.
 * Created: July, 2005
 * Author:	Rachael Bennet (srbennet@andrew)
 * ---------------------------------------------------------------------
 * 							Modifications 
 * ---------------------------------------------------------------------
 * 02/23/2006	kcunning	parse() method modified so that it will handle 
 * 							empty lines at the end of the input file.  
 * 							Comments added to code.
 * -------------------------------------------------------------------*/

package edu.cmu.radar.vendor.RoomRequest;

import java.util.*;
import java.io.*;

public class Meeting
{
	private String id;
	private String initiator;
	private int duration;
	private String type;
	private int weight;
	private String attendants;

	// Constructor
	public Meeting()
	{
		id = new String();
		initiator = new String();
		duration = 0;
		type = new String();
		weight = 0;
		attendants = new String();
	}

	// Constructor with arguments
	public Meeting(String id, String initiator, int duration, String type, int weight, String attendants)
	{
		this.id = id;
		this.initiator = initiator;
		this.duration = duration;
		this.type = type;
		this.weight = weight;
		this.attendants = attendants;
	}

	/*----------------------------------------------------------
	 * get Methods
	 * -------------------------------------------------------*/
	public String getId()
	{
		return id;
	}

	public String getInitiator()
	{
		return initiator;
	}

	public int getDuration()
	{
		return duration;
	}

	public int getDurationBlocks()
	{
		return (duration/1800);
	}

	public String getType()
	{
		return type;
	}

	public int getWeight()
	{
		return weight;
	}

	public String getAttendants()
	{
		return attendants;
	}

	/*----------------------------------------------------------
	 * set Methods
	 * -------------------------------------------------------*/
	public void setId(String id)
	{
		this.id = id;
	}

	public void setInitiator(String initiator)
	{
		this.initiator = initiator;
	}

	public void setDuration(int duration)
	{
		this.duration = duration;
	}

	public void setType(String type)
	{
		this.type = type;
	}

	public void setWeight(int weight)
	{
		this.weight = weight;
	}

	public void setAttendants(String attendants)
	{
		this.attendants = attendants;
	}


	/*----------------------------------------------------------------------
	 * parse()
	 * ---------------------------------------------------------------------
	 * Purpose:	Responsible for parsing the .meetings file.  When a meeting 
	 * 			is found a new Meeting object is created.  Meeting data is 
	 * 			gathered and stored in a hashmap.
	 * Input:	String <filename> - name of .meetings file
	 * Output:	HashMap
	 * Exceptions:	Use of try/catch block, does not throw exceptions.
	 * -------------------------------------------------------------------*/
	public static HashMap parse(InputStream input_stream)
	{
		try{
			BufferedReader file = new BufferedReader(new InputStreamReader(input_stream));
			String line = file.readLine();
			String type;
			HashMap meetingsHash = new HashMap();

			// main loop for parsing the .meetings file.  Loop terminates when readLine() returns
			// a null value or a blank line.
			while((line != null) && (line.toCharArray().length != 0)) {
				Meeting m = new Meeting();

				// Inner loop responsible for reading meeting details.  Loop terminates when readLine()
				// returns a null value (end of file), a --- delimeter or a blank line.
				while ((line != null) && (!line.equals("---")) && (line.toCharArray().length != 0)) {
					StringTokenizer tokens = new StringTokenizer(line);
					type = tokens.nextToken();

					if(type.compareTo("Id") == 0) {
						m.setId(tokens.nextToken());
					}	
					else if(type.compareTo("Initiator")==0) {
						m.setInitiator(tokens.nextToken());
					}
					else if(type.compareTo("Duration") == 0) {
						//System.out.println("getting duration " + line);
						m.setDuration((new Integer(tokens.nextToken())).intValue());
						//System.out.println("duration is " + m.getDuration());
					}
					else if(type.compareTo("Type") == 0) {
						m.setType(tokens.nextToken());
					}
					else if(type.compareTo("Weight") == 0) {
						m.setWeight((new Integer(tokens.nextToken())).intValue());
					}
					else if (type.compareTo("Attendants")==0) {
						m.setAttendants(tokens.nextToken());
					}

					line = file.readLine();
				} // end while (reading meeting details)
				
				//System.out.println(m.getId());
				meetingsHash.put(m.getId(), m);
				line = file.readLine();
			} // end while (reading meeting file)
			return meetingsHash;
		
		} catch(Exception e) { 
			e.printStackTrace();
			return null;
		}
	} // end parse()

// --------------------------------------------------------------------
} 						// end Meeting.java
// --------------------------------------------------------------------